@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Open Source Robotics Foundation
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
+ * Licensed under the Apache License, Version 3.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
@@ -23,22 +23,22 @@
 
 #include <iostream>
 
-#include <gz/physics/FindFeatures.hh>
-#include <gz/plugin/Loader.hh>
-#include <gz/physics/RequestEngine.hh>
+#include <ignition/physics/FindFeatures.hh>
+#include <ignition/plugin/Loader.hh>
+#include <ignition/physics/RequestEngine.hh>
 
-#include <gz/math/eigen3/Conversions.hh>
+#include <ignition/math/eigen3/Conversions.hh>
 
 // Features
-#include <gz/physics/ForwardStep.hh>
-#include <gz/physics/FreeJoint.hh>
-#include <gz/physics/FixedJoint.hh>
-#include <gz/physics/GetEntities.hh>
-#include <gz/physics/Joint.hh>
-#include <gz/physics/RevoluteJoint.hh>
-#include <gz/physics/dartsim/World.hh>
-#include <gz/physics/sdf/ConstructModel.hh>
-#include <gz/physics/sdf/ConstructWorld.hh>
+#include <ignition/physics/ForwardStep.hh>
+#include <ignition/physics/FreeJoint.hh>
+#include <ignition/physics/FixedJoint.hh>
+#include <ignition/physics/GetEntities.hh>
+#include <ignition/physics/Joint.hh>
+#include <ignition/physics/RevoluteJoint.hh>
+#include <ignition/physics/dartsim/World.hh>
+#include <ignition/physics/sdf/ConstructModel.hh>
+#include <ignition/physics/sdf/ConstructWorld.hh>
 
 #include <limits>
 #include <sdf/Model.hh>
@@ -47,9 +47,9 @@
 
 #include "test/Utils.hh"
 
-using namespace gz;
+using namespace ignition;
 
-using TestFeatureList = physics::FeatureList<
+using TestFeatureList = ignition::physics::FeatureList<
   physics::dartsim::RetrieveWorld,
   physics::AttachFixedJointFeature,
   physics::DetachJointFeature,
@@ -74,14 +74,14 @@ class JointFeaturesFixture : public ::testing::Test
 {
   protected: void SetUp() override
   {
-    plugin::Loader loader;
+    ignition::plugin::Loader loader;
     loader.LoadLib(dartsim_plugin_LIB);
 
-    plugin::PluginPtr dartsim =
+    ignition::plugin::PluginPtr dartsim =
         loader.Instantiate("ignition::physics::dartsim::Plugin");
 
     this->engine =
-        physics::RequestEngine3d<TestFeatureList>::From(dartsim);
+        ignition::physics::RequestEngine3d<TestFeatureList>::From(dartsim);
     ASSERT_NE(nullptr, this->engine);
   }
   protected: TestEnginePtr engine;
@@ -903,12 +903,9 @@ TEST_F(JointFeaturesFixture, LinkCountsInJointAttachDetach)
 
   auto fixedJoint = model2Body->AttachFixedJoint(model1Body);
 
-  // After attaching we expect each model to have 1 link, but the current
-  // behavior is that there are 2 links in model1 and 0 in model2
-  // EXPECT_EQ(1u, model1->GetLinkCount());
-  // EXPECT_EQ(1u, model2->GetLinkCount());
-  EXPECT_EQ(2u, model1->GetLinkCount());
-  EXPECT_EQ(0u, model2->GetLinkCount());
+  // After attaching we expect each model to have 1 link
+  EXPECT_EQ(1u, model1->GetLinkCount());
+  EXPECT_EQ(1u, model2->GetLinkCount());
 
   // now detach joint and expect model2 to start moving again
   fixedJoint->Detach();
@@ -923,7 +920,7 @@ TEST_F(JointFeaturesFixture, LinkCountsInJointAttachDetach)
 
   auto model3Body = model3->GetLink(bodyName);
   auto fixedJoint2 = model3Body->AttachFixedJoint(model2Body);
-  EXPECT_EQ(2u, model2->GetLinkCount());
+  EXPECT_EQ(1u, model2->GetLinkCount());
   fixedJoint2->Detach();
   // After detaching we expect each model to have 1 link
   EXPECT_EQ(1u, model2->GetLinkCount());
@@ -984,8 +981,8 @@ TEST_F(JointFeaturesFixture, JointAttachDetachSpawnedModel)
     sdf::Root root;
     sdf::Errors errors = root.LoadSdfString(model1Str);
     ASSERT_TRUE(errors.empty()) << errors.front();
-    ASSERT_NE(nullptr, root.ModelByIndex(0));
-    world->ConstructModel(*root.ModelByIndex(0));
+    ASSERT_NE(nullptr, root.Model());
+    world->ConstructModel(*root.Model());
   }
 
   world->Step(output, state, input);
@@ -994,8 +991,8 @@ TEST_F(JointFeaturesFixture, JointAttachDetachSpawnedModel)
     sdf::Root root;
     sdf::Errors errors = root.LoadSdfString(model2Str);
     ASSERT_TRUE(errors.empty()) << errors.front();
-    ASSERT_NE(nullptr, root.ModelByIndex(0));
-    world->ConstructModel(*root.ModelByIndex(0));
+    ASSERT_NE(nullptr, root.Model());
+    world->ConstructModel(*root.Model());
   }
 
   const std::string modelName1{"M1"};
