@@ -24,8 +24,11 @@
 #include <dart/constraint/ConstraintSolver.hpp>
 #include <dart/dynamics/BallJoint.hpp>
 #include <dart/dynamics/BoxShape.hpp>
+#include <dart/dynamics/CapsuleShape.hpp>
 #include <dart/dynamics/CylinderShape.hpp>
+#include <dart/dynamics/EllipsoidShape.hpp>
 #include <dart/dynamics/FreeJoint.hpp>
+#include <dart/dynamics/HeightmapShape.hpp>
 #include <dart/dynamics/MeshShape.hpp>
 #include <dart/dynamics/PlaneShape.hpp>
 #include <dart/dynamics/PrismaticJoint.hpp>
@@ -36,14 +39,19 @@
 #include <dart/constraint/WeldJointConstraint.hpp>
 #include <dart/dynamics/WeldJoint.hpp>
 
-#include <gz/common/Console.hh>
-#include <gz/math/eigen3/Conversions.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Mesh.hh>
+#include <ignition/common/MeshManager.hh>
+#include <ignition/math/eigen3/Conversions.hh>
+#include <ignition/math/Helpers.hh>
 
 #include <sdf/Box.hh>
 #include <sdf/Collision.hh>
+#include <sdf/Capsule.hh>
 #include <sdf/Cylinder.hh>
+#include <sdf/Ellipsoid.hh>
 #include <sdf/Geometry.hh>
+#include <sdf/Heightmap.hh>
 #include <sdf/Joint.hh>
 #include <sdf/JointAxis.hh>
 #include <sdf/Link.hh>
@@ -51,9 +59,12 @@
 #include <sdf/Mesh.hh>
 #include <sdf/Model.hh>
 #include <sdf/Sphere.hh>
+#include <sdf/Types.hh>
 #include <sdf/Visual.hh>
 #include <sdf/World.hh>
 
+#include "CustomMeshShape.hh"
+
 namespace ignition {
 namespace physics {
 namespace dartsim {
@@ -117,7 +128,20 @@ static void CopyStandardJointAxisProperties(
     const int _index, Properties &_properties,
     const ::sdf::JointAxis *_sdfAxis)
 {
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#else
+# pragma warning(push)
+# pragma warning(disable: 4996)
+#endif
+  // TODO(anyone): stop using this deprecated function
   _properties.mInitialPositions[_index] = _sdfAxis->InitialPosition();
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#else
+# pragma warning(pop)
+#endif
   _properties.mDampingCoefficients[_index] = _sdfAxis->Damping();
   _properties.mFrictions[_index] = _sdfAxis->Friction();
   _properties.mRestPositions[_index] = _sdfAxis->SpringReference();
@@ -154,7 +178,7 @@ static Eigen::Vector3d ConvertJointAxis(
   // Error while Resolving xyz. Fallback sdformat 1.6 behavior but treat
   // xyz_expressed_in = "__model__" as the old use_parent_model_frame
 
-  const Eigen::Vector3d axis = math::eigen3::convert(_sdfAxis->Xyz());
+  const Eigen::Vector3d axis = ignition::math::eigen3::convert(_sdfAxis->Xyz());
 
   if (_sdfAxis->XyzExpressedIn().empty())
     return axis;
@@ -259,6 +283,14 @@ static ShapeAndTransform ConstructSphere(
   return {std::make_shared<dart::dynamics::SphereShape>(_sphere.Radius())};
 }
 
+/////////////////////////////////////////////////
+static ShapeAndTransform ConstructCapsule(
+    const ::sdf::Capsule &_capsule)
+{
+  return {std::make_shared<dart::dynamics::CapsuleShape>(
+        _capsule.Radius(), _capsule.Length())};
+}
+
 /////////////////////////////////////////////////
 static ShapeAndTransform ConstructPlane(
     const ::sdf::Plane &_plane)
@@ -284,6 +316,15 @@ static ShapeAndTransform ConstructPlane(
           Eigen::Vector3d(planeDim, planeDim, planeDim)), tf};
 }
 
+/////////////////////////////////////////////////
+static ShapeAndTransform ConstructHeightmap(
+    const ::sdf::Heightmap & /*_heightmap*/)
+{
+  ignerr << "Heightmap construction from an SDF has not been implemented yet "
+         << "for dartsim.\n";
+  return {nullptr};
+}
+
 /////////////////////////////////////////////////
 static ShapeAndTransform ConstructMesh(
     const ::sdf::Mesh & /*_mesh*/)
@@ -301,17 +342,62 @@ static ShapeAndTransform ConstructGeometry(
 {
   if (_geometry.BoxShape())
     return ConstructBox(*_geometry.BoxShape());
+  else if (_geometry.CapsuleShape())
+  {
+    return ConstructCapsule(*_geometry.CapsuleShape());
+  }
   else if (_geometry.CylinderShape())
     return ConstructCylinder(*_geometry.CylinderShape());
+  else if (_geometry.EllipsoidShape())
+  {
+    // TODO(anyone): Replace this code when Ellipsoid is supported by DART
+    common::MeshManager *meshMgr = common::MeshManager::Instance();
+    std::string ellipsoidMeshName = std::string("ellipsoid_mesh")
+      + "_" + std::to_string(_geometry.EllipsoidShape()->Radii().X())
+      + "_" + std::to_string(_geometry.EllipsoidShape()->Radii().Y())
+      + "_" + std::to_string(_geometry.EllipsoidShape()->Radii().Z());
+    meshMgr->CreateEllipsoid(
+      ellipsoidMeshName,
+      _geometry.EllipsoidShape()->Radii(),
+      6, 12);
+    const ignition::common::Mesh * _mesh =
+      meshMgr->MeshByName(ellipsoidMeshName);
+
+    auto mesh = std::make_shared<CustomMeshShape>(*_mesh, Vector3d(1, 1, 1));
+    auto mesh2 = std::dynamic_pointer_cast<dart::dynamics::MeshShape>(mesh);
+    return {mesh2};
+  }
   else if (_geometry.SphereShape())
     return ConstructSphere(*_geometry.SphereShape());
   else if (_geometry.PlaneShape())
     return ConstructPlane(*_geometry.PlaneShape());
   else if (_geometry.MeshShape())
     return ConstructMesh(*_geometry.MeshShape());
+  else if (_geometry.HeightmapShape())
+    return ConstructHeightmap(*_geometry.HeightmapShape());
 
   return {nullptr};
 }
+
+}  // namespace
+
+dart::dynamics::BodyNode *SDFFeatures::FindBodyNode(
+    const std::string &_worldName, const std::string &_jointModelName,
+    const std::string &_linkRelativeName)
+{
+  if (_linkRelativeName == "world")
+    return nullptr;
+
+  const auto fullName = ::sdf::JoinName(
+      _worldName, ::sdf::JoinName(_jointModelName, _linkRelativeName));
+  auto it = this->linksByName.find(fullName);
+  if (it != this->linksByName.end())
+  {
+    return it->second;
+  }
+  ignerr << "Could not find link " << _linkRelativeName << " in model "
+         << _jointModelName << std::endl;
+  return nullptr;
 }
 
 /////////////////////////////////////////////////
@@ -323,20 +409,20 @@ Identity SDFFeatures::ConstructSdfWorld(
 
   const dart::simulation::WorldPtr &world = this->worlds.at(worldID);
 
-  world->setGravity(math::eigen3::convert(_sdfWorld.Gravity()));
+  world->setGravity(ignition::math::eigen3::convert(_sdfWorld.Gravity()));
 
   // TODO(MXG): Add a Physics class to the SDFormat DOM and then parse that
   // information here. For now, we'll just use dartsim's default physics
   // parameters.
 
-  for (std::size_t i=0; i < _sdfWorld.ModelCount(); ++i)
+  for (std::size_t i = 0; i < _sdfWorld.ModelCount(); ++i)
   {
     const ::sdf::Model *model = _sdfWorld.ModelByIndex(i);
 
     if (!model)
       continue;
 
-    this->ConstructSdfModel(worldID, *model);
+    this->ConstructSdfNestedModel(worldID, *model);
   }
 
   return worldID;
@@ -344,44 +430,81 @@ Identity SDFFeatures::ConstructSdfWorld(
 
 /////////////////////////////////////////////////
 Identity SDFFeatures::ConstructSdfModel(
-    const Identity &_worldID,
+    const Identity &_parentID,
     const ::sdf::Model &_sdfModel)
 {
-  // check if parent is a world
-  if (!this->worlds.HasEntity(_worldID))
+  return this->ConstructSdfModelImpl(_parentID, _sdfModel);
+}
+
+/////////////////////////////////////////////////
+Identity SDFFeatures::ConstructSdfNestedModel(const Identity &_parentID,
+                                              const ::sdf::Model &_sdfModel)
+{
+  return this->ConstructSdfModelImpl(_parentID, _sdfModel);
+}
+
+/////////////////////////////////////////////////
+Identity SDFFeatures::ConstructSdfModelImpl(
+    std::size_t _parentID,
+    const ::sdf::Model &_sdfModel)
+{
+  auto worldID = _parentID;
+  std::string modelName = _sdfModel.Name();
+  const bool isNested = this->models.HasEntity(_parentID);
+  // If this is a nested model, find the world assocated with the model
+  if (isNested)
   {
-    ignerr << "Unable to construct model: " << _sdfModel.Name() << ". "
-           << "Parent of model is not a world. " << std::endl;
-    return this->GenerateInvalidId();
+    worldID = this->GetWorldOfModelImpl(_parentID);
+    const auto &skel = this->models.at(_parentID)->model;
+    modelName = ::sdf::JoinName(skel->getName(), _sdfModel.Name());
   }
 
+  dart::dynamics::Frame *parentFrame = this->frames.at(_parentID);
+
   dart::dynamics::SkeletonPtr model =
-      dart::dynamics::Skeleton::create(_sdfModel.Name());
+      dart::dynamics::Skeleton::create(modelName);
 
   dart::dynamics::SimpleFramePtr modelFrame =
       dart::dynamics::SimpleFrame::createShared(
-        dart::dynamics::Frame::World(),
-        _sdfModel.Name()+"_frame",
-        ResolveSdfPose(_sdfModel.SemanticPose()));
+          parentFrame, modelName + "::__model__",
+          ResolveSdfPose(_sdfModel.SemanticPose()));
 
   // Set canonical link name
-  auto [modelID, modelInfo] = this->AddModel( // NOLINT
-      {model, modelFrame, _sdfModel.CanonicalLinkName()}, _worldID);
-
+  // TODO(anyone) This may not work correctly with nested models and will need
+  // to be updated once multiple canonical links can exist in a nested model
+  // https://github.com/ignitionrobotics/ign-physics/issues/209
+  auto [modelID, modelInfo] = [&] {
+    if (isNested)
+    {
+      return this->AddNestedModel(  // NOLINT
+          {model, _sdfModel.Name(), modelFrame, _sdfModel.CanonicalLinkName()},
+          _parentID, worldID);
+    }
+    else
+    {
+      return this->AddModel(  // NOLINT
+          {model, _sdfModel.Name(), modelFrame, _sdfModel.CanonicalLinkName()},
+          worldID);
+    }
+  }();
   model->setMobile(!_sdfModel.Static());
   model->setSelfCollisionCheck(_sdfModel.SelfCollide());
 
   auto modelIdentity =
       this->GenerateIdentity(modelID, this->models.at(modelID));
 
-  // First, construct all links
+  // First, recursively construct nested models
+  for (std::size_t i = 0; i < _sdfModel.ModelCount(); ++i)
+  {
+    this->ConstructSdfModelImpl(modelID, *_sdfModel.ModelByIndex(i));
+  }
+  // then, construct all links
   for (std::size_t i=0; i < _sdfModel.LinkCount(); ++i)
   {
     this->FindOrConstructLink(
           model, modelIdentity, _sdfModel, _sdfModel.LinkByIndex(i)->Name());
   }
 
-
   // Next, join all links that have joints
   for (std::size_t i=0; i < _sdfModel.JointCount(); ++i)
   {
@@ -393,11 +516,76 @@ Identity SDFFeatures::ConstructSdfModel(
       continue;
     }
 
-    dart::dynamics::BodyNode * const parent = this->FindOrConstructLink(
-          model, modelIdentity, _sdfModel, sdfJoint->ParentLinkName());
+    // Resolve parent and child frames to links
+    std::string parentLinkName;
+    ::sdf::Errors errors = sdfJoint->ResolveParentLink(parentLinkName);
+    if (!errors.empty())
+    {
+      ignerr << "The link of the parent frame [" << sdfJoint->ParentLinkName()
+             << "] of joint [" << sdfJoint->Name() << "] in model ["
+             << modelName
+             << "] could not be resolved. The joint will not be constructed\n";
+      for (const auto &error : errors)
+      {
+        ignerr << error << std::endl;
+      }
+      continue;
+    }
+    std::string childLinkName;
+    errors = sdfJoint->ResolveChildLink(childLinkName);
+    if (!errors.empty())
+    {
+      ignerr << "The link of the child frame [" << sdfJoint->ChildLinkName()
+             << "] of joint [" << sdfJoint->Name() << "] in model ["
+             << modelName
+             << "] could not be resolved. The joint will not be constructed\n";
+      for (const auto &error : errors)
+      {
+        ignerr << error << std::endl;
+      }
+      continue;
+    }
 
-    dart::dynamics::BodyNode * const child = this->FindOrConstructLink(
-          model, modelIdentity, _sdfModel, sdfJoint->ChildLinkName());
+    const ::sdf::Link *parentSdfLink = _sdfModel.LinkByName(parentLinkName);
+    if (nullptr == parentSdfLink && parentLinkName != "world")
+    {
+      ignerr << "The link [" << parentLinkName << "] of the parent frame ["
+             << sdfJoint->ParentLinkName() << "] of joint [" << sdfJoint->Name()
+             << "] in model [" << modelName
+             << "] could not be resolved. The joint will not be constructed\n";
+      continue;
+    }
+
+    const ::sdf::Link *childSdfLink = _sdfModel.LinkByName(childLinkName);
+    if (nullptr == childSdfLink)
+    {
+      ignerr << "The link [" << childLinkName << "] of the child frame ["
+             << sdfJoint->ChildLinkName() << "] of joint [" << sdfJoint->Name()
+             << "] in model [" << modelName
+             << "] could not be resolved. The joint will not be constructed\n";
+      continue;
+    }
+
+    auto * const parent =
+      FindBodyNode(this->worlds[worldID]->getName(), modelName, parentLinkName);
+
+    if (nullptr == parent && parentLinkName != "world")
+    {
+      ignerr << "The parent [" << sdfJoint->ParentLinkName() << "] of joint ["
+             << sdfJoint->Name() << "] in model [" << modelName
+             << "] was not found. The joint will not be constructed\n";
+      continue;
+    }
+
+    auto * const child =
+      FindBodyNode(worlds[worldID]->getName(), modelName, childLinkName);
+    if (nullptr == child)
+    {
+      ignerr << "The child of joint [" << sdfJoint->Name() << "] in model ["
+             << modelName
+             << "] was not found. The joint will not be constructed\n";
+      continue;
+    }
 
     this->ConstructSdfJoint(modelInfo, *sdfJoint, parent, child);
   }
@@ -414,10 +602,18 @@ Identity SDFFeatures::ConstructSdfLink(
   dart::dynamics::BodyNode::Properties bodyProperties;
   bodyProperties.mName = _sdfLink.Name();
 
-  const math::Inertiald &sdfInertia = _sdfLink.Inertial();
+  const ignition::math::Inertiald &sdfInertia = _sdfLink.Inertial();
   bodyProperties.mInertia.setMass(sdfInertia.MassMatrix().Mass());
 
-  const Eigen::Matrix3d I_link = math::eigen3::convert(sdfInertia.Moi());
+  // TODO(addisu) Resolve the pose of inertials when frame information is
+  // availabile for ignition::math::Inertial
+  const Eigen::Matrix3d R_inertial{
+        math::eigen3::convert(sdfInertia.Pose().Rot())};
+
+  const Eigen::Matrix3d I_link =
+      R_inertial
+      * math::eigen3::convert(sdfInertia.Moi())
+      * R_inertial.inverse();
 
   bodyProperties.mInertia.setMoment(I_link);
 
@@ -445,7 +641,20 @@ Identity SDFFeatures::ConstructSdfLink(
 
   dart::dynamics::BodyNode * const bn = result.second;
 
-  const std::size_t linkID = this->AddLink(bn);
+  auto worldID = this->GetWorldOfModelImpl(_modelID);
+  if (worldID == INVALID_ENTITY_ID)
+  {
+    ignerr << "World of model [" << modelInfo.model->getName()
+           << "] could not be found when creating link [" << _sdfLink.Name()
+           << "]\n";
+    return this->GenerateInvalidId();
+  }
+
+  auto world = this->worlds.at(worldID);
+  const std::string fullName = ::sdf::JoinName(
+      world->getName(),
+      ::sdf::JoinName(modelInfo.model->getName(), bn->getName()));
+  const std::size_t linkID = this->AddLink(bn, fullName, _modelID);
   this->AddJoint(joint);
 
   auto linkIdentity = this->GenerateIdentity(linkID, this->links.at(linkID));
@@ -488,11 +697,77 @@ Identity SDFFeatures::ConstructSdfJoint(
     const ::sdf::Joint &_sdfJoint)
 {
   const auto &modelInfo = *this->ReferenceInterface<ModelInfo>(_modelID);
+
+  if (_sdfJoint.ChildLinkName() == "world")
+  {
+    ignerr << "Asked to create a joint with the world as the child in model "
+           << "[" << modelInfo.model->getName() << "]. This is currently not "
+           << "supported\n";
+
+    return this->GenerateInvalidId();
+  }
+
+  // If we get an error here, one of two things has occured:
+  // 1. The Model _sdfJoint came from is invalid, i.e, had errors during
+  //    sdf::Root::Load and ConstructSdfJoint was called regardless of the
+  //    errors. Resolving for the parent link may fail for any number of reasons
+  //    and should be reported.
+  // 2. ConstructSdfJoint is being called with an sdf::Joint that was
+  //    constructed by the user instead of one obtained from an sdf::Model
+  //    object. In this case, the joint does not have a valid frame graph and it
+  //    cannot be used to resolve for the parent link name. However, this can
+  //    still be a valid use case for ign-gazebo that sends DOM objects
+  //    piecemeal with all links and poses resolved.
+  // Since (1) is an error that should be reported and (2) might be a valid use
+  // case, the solution is, when an error is encountered, we first assume (2)
+  // and set the parent and child link names to whatever returned from
+  // sdf::Joint::ParentLinkName() and sdf::Joint::ChildLinkName respectively.
+  // Then we check if a body node with the same relative name exists in DART. If
+  // the link is nested inside a child model, it will be necessary to split the
+  // name to identify the correct parent skeleton. If the corresponding body
+  // node is found, an error will not be printed.
+  //
+  const std::size_t worldID = this->GetWorldOfModelImpl(_modelID);
+  auto & world = this->worlds.at(worldID);
+
+  std::string parentLinkName;
+  const auto resolveParentErrors = _sdfJoint.ResolveParentLink(parentLinkName);
+  if (!resolveParentErrors.empty()) {
+    // It's possible this wasn't created from an sdf::Model object, like
+    // SDFFeatures_TEST.WorldIsParentOrChild. Try using raw ParentLinkName() in
+    // that case
+    parentLinkName = _sdfJoint.ParentLinkName();
+  }
+
   dart::dynamics::BodyNode * const parent =
-      modelInfo.model->getBodyNode(_sdfJoint.ParentLinkName());
+    FindBodyNode(world->getName(), modelInfo.model->getName(), parentLinkName);
+
+  std::string childLinkName;
+  const auto childResolveErrors = _sdfJoint.ResolveChildLink(childLinkName);
+  if (!childResolveErrors.empty()) {
+    childLinkName = _sdfJoint.ChildLinkName();
+  }
 
   dart::dynamics::BodyNode * const child =
-      modelInfo.model->getBodyNode(_sdfJoint.ChildLinkName());
+    FindBodyNode(world->getName(), modelInfo.model->getName(), childLinkName);
+
+  if (nullptr == parent && parentLinkName != "world")
+  {
+    ignerr << "The link of the parent frame [" << _sdfJoint.ParentLinkName()
+           << "] with resolved link name [" << parentLinkName
+           << "] of joint [" << _sdfJoint.Name()
+           << "] could not be resolved. The joint will not be constructed\n";
+    return this->GenerateInvalidId();
+  }
+  if (nullptr == child)
+  {
+    ignerr << "The link of the child frame [" << _sdfJoint.ChildLinkName()
+           << "] with resolved link name [" << childLinkName
+           << "] of joint [" << _sdfJoint.Name() << "] in model ["
+           << modelInfo.model->getName()
+           << "] could not be resolved. The joint will not be constructed\n";
+    return this->GenerateInvalidId();
+  }
 
   return ConstructSdfJoint(modelInfo, _sdfJoint, parent, child);
 }
@@ -516,6 +791,8 @@ Identity SDFFeatures::ConstructSdfCollision(
   if (!shape)
   {
     // The geometry element was empty, or the shape type is not supported
+    ignerr << "The geometry element of collision [" << _collision.Name() << "] "
+           << "couldn't be created\n";
     return this->GenerateInvalidId();
   }
 
@@ -562,8 +839,26 @@ Identity SDFFeatures::ConstructSdfCollision(
     }
     if (odeFriction->HasElement("fdir1"))
     {
-      math::Vector3d fdir1 = odeFriction->Get<math::Vector3d>("fdir1");
+      auto frictionDirectionElem = odeFriction->GetElement("fdir1");
+      math::Vector3d fdir1 = frictionDirectionElem->Get<math::Vector3d>();
       aspect->setFirstFrictionDirection(math::eigen3::convert(fdir1));
+
+      const std::string kExpressedIn = "ignition:expressed_in";
+      if (frictionDirectionElem->HasAttribute(kExpressedIn))
+      {
+        auto skeleton = bn->getSkeleton();
+        auto directionFrameBodyNode = skeleton->getBodyNode(
+          frictionDirectionElem->Get<std::string>(kExpressedIn));
+        if (nullptr != directionFrameBodyNode)
+        {
+          aspect->setFirstFrictionDirectionFrame(directionFrameBodyNode);
+        }
+        else
+        {
+          ignwarn << "Failed to get body node for [" << _collision.Name()
+                  << "], not setting friction direction frame." << std::endl;
+        }
+      }
     }
 
     const auto &surfaceBounce = _collision.Element()
@@ -630,6 +925,8 @@ Identity SDFFeatures::ConstructSdfVisual(
   if (!shape)
   {
     // The geometry element was empty, or the shape type is not supported
+    ignerr << "The geometry element of visual [" << _visual.Name() << "] "
+           << "couldn't be created\n";
     return this->GenerateInvalidId();
   }
 
@@ -652,7 +949,7 @@ Identity SDFFeatures::ConstructSdfVisual(
   // intended for the physics?
   if (_visual.Material())
   {
-    const math::Color &color = _visual.Material()->Ambient();
+    const ignition::math::Color &color = _visual.Material()->Ambient();
     node->getVisualAspect()->setColor(
           Eigen::Vector4d(color.R(), color.G(), color.B(), color.A()));
   }
@@ -736,11 +1033,10 @@ Identity SDFFeatures::ConstructSdfJoint(
 
   {
     auto childsParentJoint = _child->getParentJoint();
-    std::string parentName = worldParent? "world" : _parent->getName();
     if (childsParentJoint->getType() != "FreeJoint")
     {
       ignerr << "Asked to create a joint between links "
-             << "[" << parentName << "] as parent and ["
+             << "[" << _parent->getName() << "] as parent and ["
              << _child->getName() << "] as child, but the child link already "
              << "has a parent joint of type [" << childsParentJoint->getType()
              << "].\n";
@@ -750,7 +1046,7 @@ Identity SDFFeatures::ConstructSdfJoint(
     {
       // TODO(MXG): Add support for non-tree graph structures
       ignerr << "Asked to create a closed kinematic chain between links "
-             << "[" << parentName << "] and [" << _child->getName()
+             << "[" << _parent->getName() << "] and [" << _child->getName()
              << "], but that is not supported by the dartsim wrapper yet.\n";
       return this->GenerateInvalidId();
     }
@@ -857,6 +1153,11 @@ Identity SDFFeatures::ConstructSdfJoint(
   joint->setTransformFromParentBodyNode(parent_T_prejoint_final);
 
   const std::size_t jointID = this->AddJoint(joint);
+  // Increment BodyNode version since the child could be moved to a new skeleton
+  // when a joint is created.
+  // TODO(azeey) Remove incrementVersion once DART has been updated to
+  // internally increment the BodyNode's version after Joint::moveTo.
+  _child->incrementVersion();
 
   return this->GenerateIdentity(jointID, this->joints.at(jointID));
 }
